/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.ajax;

import org.mentawai.core.Action;
/**
 * 
 * @author Rubem Azenha (rubem.azenha@gmail.com)
 * A class for renderize Ajax reponses. A AjaxRender
 * will comunly be associated with a AjaxConsequence. 
 * The AjaxRender has the responsability of analizing
 * the output of the action and create a response based on that.
 * The AjaxRender has to give a AjaxResponse. The AjaxResponse will write the renderized response
 * to the servlet output.
 */
public interface AjaxRender {
    
    /**
     * Content-type for text/html.
     */
    public static final String TEXT_HTML = "text/html";
    
    /**
     * Content-type for text/xml.
     */
    public static final String TEXT_XML = "text/xml";

    
	/**
	 * Renderizes the action`s result to a (XML) org.jdom.Document.
	 */
	public String renderize(Action action) throws Exception;
    
    /**
     * Gets the content type that has to be setted in the response.
     * @return the content type.
     */
    public String getContentType();
}
 