/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.ajax.renders;

import java.util.Collection;

import net.sf.json.JSONArray;

import org.mentawai.ajax.AjaxRender;
import org.mentawai.core.Action;
import org.mentawai.core.ConsequenceException;

/**
 * Expect a java.util.Collection or a JSONArray in the output.
 * 
 * @author Davi Luan Carneiro
 * @author Rubem Azenha (rubem.azenha@gmail.com)
 */
public class JSONArrayAjaxRender implements AjaxRender {

    /** Default key */
    public static final String JSON_ARRAY_ATTR = "json_array";

    private String key = JSON_ARRAY_ATTR;

    public JSONArrayAjaxRender() {
    }

    public JSONArrayAjaxRender(String key) {
        this.key = key;
    }

    /**
     * @see org.mentawai.ajax.AjaxRender#renderize(org.mentawai.core.Action)
     */
    public String renderize(Action action) throws Exception {
        Object obj = action.getOutput().getValue(key);
        if (obj == null) {
            throw new ConsequenceException("Invalid key: " + key);
        }

        JSONArray json;
        if (obj instanceof Collection) {
            json = new JSONArray((Collection) obj);
        } else if (obj instanceof JSONArray) {
            json = (JSONArray) obj;
        } else {
            throw new ConsequenceException("The value of key " + key
                    + " isn't a Collection or JSONArray");
        }

        return json.toString();
    }

    public String getContentType() {
        return TEXT_HTML;
    }
}
