package org.mentawai.ajax.renders;

import net.sf.json.JSONObject;

import org.mentawai.ajax.AjaxRender;
import org.mentawai.core.Action;

/**
 * A Ajax Render that gets a Java Object and transforms it into a JSON Object.
 * The render expect an object in the actions output, identified by the key
 * "object" by default, but you can change it.
 * 
 * @author Rubem Azenha (rubem.azenha@gmail.com)
 */
public class JSONObjectAjaxRender implements AjaxRender {

    /**
     * The default key that identifies the object that will be tranformed into a
     * JSON object. The default value is "object".
     */
    private static final String JSONOBJECT_KEY = "object";

    /**
     * The Key that identifies the object that will be tranformed into a a JSON
     * Object.
     */
    private String key = JSONOBJECT_KEY;

    /**
     * Creates a new instance of the JSONObjectAjaxRender, defining the key that
     * will be used to identify the object that will be transformed into a JSON
     * Object.
     * 
     * @param key
     *            The key that will be used to identify the object that will be
     *            transformed into a JSON object.
     */
    public JSONObjectAjaxRender(String key) {
        this.key = key;
    }

    /**
     * Transforms an object in the actions output identified by the "key"
     * attribute into a JSON object.
     * 
     * @param action
     *            The action which the output will be used to get the object
     *            that will be tranformed into a JSON object.
     * @return The JSON object representation or "null" if no object is found in
     *         the actions output identified by the "key" attribute.
     */
    public String renderize(Action action) throws Exception {
        Object object = action.getOutput().getValue(key);
        if (object == null) {
            return "null";
        }
        return JSONObject.fromBean(object).toString();
    }

    public String getContentType() {
        return TEXT_HTML;
    }

}
