/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.ajax.renders;

import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;

import org.jdom.Document;
import org.jdom.Element;
import org.mentawai.ajax.AjaxRender;
import org.mentawai.ajax.DOMUtils;
import org.mentawai.core.Action;
/**
 * 
 * @author Rubem Azenha (rubem.azenha@gmail.com)
 * <p>A AjaxRender that gets map from the action`s output
 * and creates a XML structure with the contents of this
 * map.</p>
 * <p>For example, a Map with this content: <br/>
 * <pre>
 * |      key      |      value      |
 * |     akey      |      avalue     |
 * | yetAnotherKey | yetAnotherValue |
 * </pre>
 * <br/>
 * Would create the folowing XML structure:
 * <pre>
 * &ltmap&gt
 *     &ltentry key="akey"&gtavalue&lt/entry&gt
 *     &ltentry key="yetAnotherKey"&gtyetAnotherValue&lt/entry&gt
 *  &lt/map&gt   
 * </pre>
 * </p>
 * <p>The tag names ("map" & "entry") may be changed.</p>
 * <p>Then you can use your favorite JavaScript parser (or use your own)
 * to parse the generated XML strucure and interact it in your code.</p>
 */
public class MapAjaxRender implements AjaxRender {
	
	public static final String DEFAULT_MAP_ATTR = "map_attr";
	public static final String FATHER = "map";
	public static final String CHILD = "entry";
	public static final String KEY = "key"; 
	
	
	
	private String mapAttr;
	private String father;
	private String child;
	private String key;
	
	public MapAjaxRender(String child, String father, String attr, String key) {
		this.child = child;
		this.father = father;
		this.mapAttr = attr;
		this.key = key;
	}
	
	public MapAjaxRender(String child, String father, String key) {
		this.child = child;
		this.father = father;
		this.key = key;
	}

	public MapAjaxRender(String mapAttr) {
		this.mapAttr = mapAttr;
		this.father = FATHER;
		this.child = CHILD;
		this.key = KEY;
	}
	
	public MapAjaxRender(){
		 this(DEFAULT_MAP_ATTR);
	}

	
	
	
	
	public String renderize(Action action) throws Exception {
		
		Map map = (Map) action.getOutput().getValue(mapAttr);
		Document document = new Document();
		Element mapElement  = new Element(this.father);
		
		for (Iterator iterator = map.entrySet().iterator(); iterator.hasNext();) {
			Element child = new Element(this.child);
			Entry entry = (Entry) iterator.next();
			
			String key = entry.getKey().toString();
			String value = entry.getValue().toString();
			
			child.setAttribute(this.key,key);
			child.setText(value);
			
			mapElement.addContent(child);
		}
		
		document.setRootElement(mapElement);
		return DOMUtils.getDocumentAsString(document);
	}

    public String getContentType() {
        return TEXT_XML;
    }


}
