/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.authorization;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/**
 * @author Sergio Oliveira
 */
public class Group implements Serializable {
    
    private String name;
    private List<Permission> permissions;
    
    public Group(String name) {
        this.name = name;
    }
    
    public Group(String name, List permissions) {
        this(name);
        this.permissions = new ArrayList<Permission>(permissions.size());
        Iterator iter = permissions.iterator();
        while(iter.hasNext()) {
            Object obj = iter.next();
            if (obj instanceof Permission) {
                Permission p = (Permission) obj;
                this.permissions.add(p);
            } else if (obj instanceof String) {
                String s = (String) obj;
                this.permissions.add(new Permission(s));
            }
        }
    }
    
    public Group(String name, String permissions) {
        this(name);
        StringTokenizer st = new StringTokenizer(permissions, ",");
        this.permissions = new ArrayList<Permission>(st.countTokens());
        while(st.hasMoreTokens()) {
            this.permissions.add(new Permission(st.nextToken().trim()));
        }
    }
    
    public Group addPermission(String permission) {
        return addPermission(new Permission(permission));
    }
    
    public Group addPermission(Permission p) {
        if (permissions == null) {
            permissions = new LinkedList<Permission>();
        }
        permissions.add(p);
        return this;
    }
    
    public String getName() {
        return name;
    }
    
    public boolean hasPermission(String permission) {
        if (permissions == null) return false;
        Iterator<Permission> iter = permissions.iterator();
        while(iter.hasNext()) {
            Permission p = iter.next();
            if (p.getName().equals(permission)) {
                return true;
            }
        }
        return false;
    }
    
    public boolean hasPermission(Permission p) {
        if (permissions == null) return false;
        return permissions.contains(p);
    }
    
    public String toString() {
        return name;
    }
    
    public int hashCode() {
        return name.hashCode();
    }
    
    public boolean equals(Object obj) {
        if (obj instanceof Group) {
            Group g = (Group) obj;
            if (g.name.equals(this.name)) return true;
        }
        return false;
    }
}
	
