package org.mentawai.log;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.text.Format;
import java.text.SimpleDateFormat;
import java.util.Date;

public class SimpleLogger implements Logger {
    
    private PrintWriter out;
    
    private final Format header = getHeaderFormat();
    
    private final Format rollFile = getRollFileFormat();
    
    private final MutableLong myLong = new MutableLong();
    
    private boolean enable = false;
    
    private File outputFile = null;
    
    public SimpleLogger(PrintWriter out) {
        
        this.out = out;
        
        printTopHeader();
        
    }
    
    public SimpleLogger(String filename) throws IOException {
        
        this.outputFile = new File(filename);
        
        this.out = new PrintWriter(new FileWriter(outputFile), false);
        
        printTopHeader();
        
    }
    
    public SimpleLogger(File file) throws IOException {
        
        this.outputFile = file;
        
        this.out = new PrintWriter(new FileWriter(outputFile), false);
        
        printTopHeader();
        
    }
    
    public SimpleLogger(PrintStream stream) {

        this.out = new PrintWriter(new OutputStreamWriter(stream), true);
    }
    
    
    public synchronized void roll() throws IOException {
        
        if (outputFile == null || !outputFile.exists()) return;
        
        out.close();
        
        String file = outputFile.getAbsoluteFile() + rollFile.format(new Long(System.currentTimeMillis()));
        
        outputFile.renameTo(new File(file));
        
        out = new PrintWriter(new FileWriter(outputFile), false);
        
        printTopHeader();
        
    }
    
    public void enable(boolean flag) {
        
        this.enable = flag;
    }
    
    protected void printTopHeader() {
        
        out.println("LOG OPENED - " + (new Date()).toString());
    }
    
    protected Format getRollFileFormat() {
        
        return new SimpleDateFormat("-dd/MM/yyyy-HH:mm:ss");
    }
    
    protected Format getHeaderFormat() {
        
        return new SimpleDateFormat("dd.HH:mm:ss");
    }
    
    protected synchronized void header() {
        
        // here just for the heck of it and to show up that we care about performance,
        // we are not creating one Long object for every log message because that would post an overhead to the GC
        
        myLong.setValue(System.currentTimeMillis());
        
        out.print(header.format(myLong));
        
        out.print(' ');
        
    }
    
    public synchronized void log(String msg) {
        
        if (!enable) return;
        
        header();
        
        out.println(msg);
        
        out.flush();
        
    }
    
    public synchronized void log(Object o1) {
        
        log(o1, null, null, null, null, null, null, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2) {
        
        log(o1, o2, null, null, null, null, null, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3) {
        
        log(o1, o2, o3, null, null, null, null, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4) {
        
        log(o1, o2, o3, o4, null, null, null, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4, Object o5) {
        
        log(o1, o2, o3, o4, o5, null, null, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4, Object o5, Object o6) {
        
        log(o1, o2, o3, o4, o5, o6, null, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4, Object o5, Object o6, Object o7) {
        
        log(o1, o2, o3, o4, o5, o6, o7, null, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4, Object o5, Object o6, Object o7, Object o8) {
        
        log(o1, o2, o3, o4, o5, o6, o7, o8, null, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4, Object o5, Object o6, Object o7, Object o8, Object o9) {
        
        log(o1, o2, o3, o4, o5, o6, o7, o8, o9, null);
    }
    
    public synchronized void log(Object o1, Object o2, Object o3, Object o4, Object o5, Object o6, Object o7, Object o8, Object o9, Object o10) {
        
        if (!enable) return;
        
        header();
        
        if (o1 != null) out.print(o1.toString());
        
        if (o2 != null) {
            
            out.print(' ');
            
            out.print(o2.toString());
        }
        
        if (o3 != null) {
            
            out.print(' ');
            
            out.print(o3.toString());
        }

        if (o4 != null) {
            
            out.print(' ');
            
            out.print(o4.toString());
        }

        if (o5 != null) {
            
            out.print(' ');
            
            out.print(o5.toString());
        }

        if (o6 != null) {
            
            out.print(' ');
            
            out.print(o6.toString());
        }

        if (o7 != null) {
            
            out.print(' ');
            
            out.print(o7.toString());
        }

        if (o8 != null) {
            
            out.print(' ');
            
            out.print(o8.toString());
        }

        if (o9 != null) {
            
            out.print(' ');
            
            out.print(o9.toString());
        }

        if (o10 != null) {
            
            out.print(' ');
            
            out.print(o10.toString());
        }
        
        out.println();
        
        out.flush();

    }
    
    private static class MutableLong extends Number {
        
        private long value;
        
        public void setValue(long value) {
            
            this.value = value;
        }
        
        public int intValue() {
            
            if (value <= Integer.MAX_VALUE) {
                
                return (int) value;
            }
            
            throw new IllegalStateException("Number is too big to be returned as Integer: " + value);
        }

        public long longValue() {
            
            return value;
            
        }

        public float floatValue() {
            
            return value;
            
        }

        public double doubleValue() {
            
            return value;
        }
    }
    
}