/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.rule;

import java.text.DateFormat;
import java.text.ParseException;
import java.util.Locale;
import java.util.Map;

 /**
  * @author Robert Anderson Nogueira de Oliveira
  */
 public class DateRule extends LocaleRule {
	 
     private static final int STYLE = DateFormat.SHORT;
     
     private int style = STYLE;
     
    /**
      * Creates a rule using the default DateFormat style (SHORT).
      */
     public DateRule() {
     }
 
     /**
      * Creates a rule using the given DateFormat style.
      *
      * @param style The DateFormat style. (Ex: DateFormat.SHORT, DateFormat.FULL, etc.)
      */    
     public DateRule(int style) {
         this.style = style;
     }
     
     public boolean check(Object object, Locale locale) {
         if (object instanceof String) {
             String s = (String) object;
             DateFormat df = DateFormat.getDateInstance(style, locale);
             df.setLenient(false);
             try {
                 df.parse(s);
                 return true;
             } catch(ParseException e) {
                 return false;
             }
         }
         return false;
     }
     
     public Map<String, String> getTokens() {
         return null;
     }
     
 }