/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.rule;

import java.util.Map;

import org.mentawai.core.Input;

/**
 * A validation rule that compares two action input fields for equality.
 *
 * @author Sergio Oliveira
 */
public class EqualRule extends CrossRule {
	
	private String field1;
	private String field2;
	
    /**
     * Creates a EqualRule for comparing the fields given.
     *
     * @param field1 The first field
     * @param field2 The second file
     */
	public EqualRule(String field1, String field2) {
		this.field1 = field1;
		this.field2 = field2;
	}
	
	public boolean check(Input input) {
		Object value1 = input.getValue(field1);
		Object value2 = input.getValue(field2);
		if (value1 == null || value2 == null) return true; // maybe optional!
		if (value1.toString().trim().equals("") || value2.toString().trim().equals("")) return true; // maybe optional
		return value1.equals(value2);
	}
	
	public Map<String, String> getTokens() {
		return null;
	}
}
