/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.tag.authorization;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;

import javax.servlet.jsp.JspException;

import org.mentawai.action.BaseLoginAction;
import org.mentawai.authorization.AuthorizationManager;
import org.mentawai.tag.util.ConditionalTag;

/**
 * @author Sergio Oliveira
 */
public class HasAuthorization extends ConditionalTag {
    
    private List<String> groups;
    private List<String> permissions;
    
    public void setGroups(String groups) {
        StringTokenizer st = new StringTokenizer(groups, ",");
        this.groups = new ArrayList<String>(st.countTokens());
        while(st.hasMoreTokens()) {
            this.groups.add(st.nextToken().trim());
        }
    }
    
    public void setPermission(String permission) {
        setPermissions(permission);
    }
    
    public void setPermissions(String permissions) {
        StringTokenizer st = new StringTokenizer(permissions, ",");
        this.permissions = new ArrayList<String>(st.countTokens());
        while(st.hasMoreTokens()) {
            this.permissions.add(st.nextToken().trim());
        }
    }
    
    public boolean testCondition() throws JspException {

        List usergroups = BaseLoginAction.getUserGroups(session);
        if (usergroups == null || usergroups.size() == 0) {
			return false;
		}
        
        boolean ok = false;
        
        if (groups != null && groups.size() > 0) {
            for(int i=0;i<groups.size();i++) {
                for(int j=0;j<usergroups.size();j++) {
                    String group = groups.get(i).toString();
                    String usergroup = usergroups.get(j).toString();
                    if (usergroup.equals(group)) {
                        ok = true;
                        i = groups.size();
                        j = usergroups.size();
                    }
                }
            }
            if (!ok) {
                return false;
            }
        }
        
        if (permissions != null && permissions.size() > 0) {
            Iterator iter = usergroups.iterator();
            while(iter.hasNext()) {
                String usergroup = iter.next().toString();
                if (AuthorizationManager.checkAny(usergroup, permissions)) {
                    ok = true;
                    break;
                }
            }
            if (!ok) {
                return false;
            }
        }
        
        if (!ok) {
            return false;
        }

        return true;
    }
}

    