/*
 * Mentawai Web Framework http://mentawai.lohis.com.br/
 * Copyright (C) 2005  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentawai.transaction;

import java.lang.reflect.Method;

/**
 * @author Rubem Azenha
 */
public class HibernateTransaction implements Transaction {
	
	private static Method beginTransaction;
	private static Method commitTransaction;
	private static Method rollbackTransaction;
	private static final String SESSION_CLASS = "org.hibernate.Session";
	private static final String TRANSACTION_CLASS = "org.hibernate.Transaction";
	private static final String BEGIN_TRANSACTION = "beginTransaction";
	private static final String COMMIT = "commit";
	private static final String ROLLBACK = "rollback";
	
	private Object session = null;
	private Object transaction = null;
    private boolean active = false;
    private boolean commited = false;
    private boolean rolledback = false;
    
    public HibernateTransaction() { }
    
	public HibernateTransaction(Object session) {
        this.session = session;
    }
    
    public HibernateTransaction(Object session, Object transaction) {
        this(session);
        this.transaction = transaction;
    }
    
    public void setSession(Object session) {
        this.session = session;
    }
    
    public void setTransaction(Object transaction) {
        this.transaction = transaction;
    }
	
	public void begin() throws Exception {
        if (active || commited || rolledback) throw new IllegalStateException("Cannot begin transaction again!");
        if (session == null) throw new IllegalStateException("HibernateTransaction does not have a hibernate session!");
        
		if (beginTransaction == null) {
			Class sessionClass = Class.forName(SESSION_CLASS);
            Class transactionClass = Class.forName(TRANSACTION_CLASS);
            
			beginTransaction = sessionClass.getMethod(BEGIN_TRANSACTION, new Class[0]);
			commitTransaction = transactionClass.getMethod(COMMIT, new Class[0]);
			rollbackTransaction = transactionClass.getMethod(ROLLBACK, new Class[0]);
        }
        
        // by Sergio: check if transaction was passed in constructor...
        if (transaction == null) {
    		transaction = beginTransaction.invoke(session, new Object[0]);
        }
		active = true;
	}

	public void commit() throws Exception {
		if (rolledback) throw new IllegalStateException("Tried to commit but transaction is already rolledback!");
		if (!commited) commitTransaction.invoke(transaction, new Object[0]);
		active = false;
		commited = true;
	}

	public void rollback() throws Exception {
		if (commited) throw new IllegalStateException("Tried to rollback but transaction is already commited!");
		if (!rolledback) rollbackTransaction.invoke(transaction, new Object[0]);
		active = false;
		rolledback = true;
	}

	public boolean isActive() {
		return active;
	}

	public boolean wasCommited() {
		return commited;
	}

	public boolean wasRolledBack() {
		return rolledback;
	}

	public Object getSession() {
		return session;
	}

	public Object getTransaction() {
		return transaction;
	}
}